@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = 2.1;
+our $VERSION = 2.4; # local revision: b
 
 use Math::Business::SMA;
 use Math::Business::EMA;
@@ -26,14 +26,27 @@ sub new {
         cy  => undef,
     }, $class;
 
-    my $days = shift;
-    if( defined $days ) {
-        $this->set_days( $days );
+    my $alpha = shift;
+    if( defined $alpha ) {
+        $this->set_alpha( $alpha );
     }
 
     return $this;
 }
 
+sub set_alpha {
+    my $this  = shift;
+    my $alpha = shift;
+
+    # NOTE: this alpha is different than you might think ... it's really inverse alpha
+    # Wilder uses alpha=14 instead of alpha=(1/14) like you might expect
+
+    my $days = 2*$alpha - 1; # so days is 2*$alpha-1 instead of the expected 2*(1/$alpha)-1
+
+    eval { $this->set_days( $days ) };
+    croak "set_alpha() is basically set_days(2*$alpha-1), which complained: $@" if $@;
+}
+
 sub set_standard {
     my $this = shift;
     my $rm   = ref $this->{U};
@@ -113,19 +126,6 @@ sub insert {
     $this->{cy} = $close_yesterday;
 }
 
-sub start_with {
-    my $this = shift;
-    my ($U,$D,$cy) = @_;
-
-    $this->{U}->start_with( $U );
-    $this->{D}->start_with( $U );
-    $this->{cy} = $cy;
-}
-
-sub query_EMA_U { my $this = shift; $this->{U}->query }
-sub query_EMA_D { my $this = shift; $this->{D}->query }
-sub query_cy    { my $this = shift; $this->{cy} }
-
 sub query {
     my $this = shift;
 
@@ -143,12 +143,13 @@ Math::Business::RSI - Technical Analysis: Relative Strength Index
   use Math::Business::RSI;
 
   my $rsi = new Math::Business::RSI;
-     $rsi->set_days(14);
+     $rsi->set_alpha(14); # issues a set days of 2*14-1
+     $rsi->set_days(27);  # equivilent to set_alpha(14)
 
-  # alternatively/equivilently
+  # equivelent to set_days(27)/set_alpha(14):
   my $rsi = new Math::Business::RSI(14);
 
-  # or to just get the recommended model ... (14)
+  # or to just get the recommended model ... set_alpha(14)
   my $rsi = Math::Business::RSI->recommended;
 
   my @closing_values = qw(
@@ -167,35 +168,45 @@ Math::Business::RSI - Technical Analysis: Relative Strength Index
       print "RSI: n/a.\n";
   }
 
-  # you may use this to kick start 
-  $rsi->start_with( $U, $D, $cy );
-
-  # you may fetch those values with these
-  my $U  = $rsi->query_EMA_U;
-  my $D  = $rsi->query_EMA_D;
-  my $cy = $rsi->query_cy; # (close yesterday)
-
 =head1 RESEARCHER
 
 The RSI was designed by J. Welles Wilder Jr in 1978.
 
 According to Wilder, a security is "overbought" it the RSI reaches an upper
-bound of 0.70 and is "oversold" when it moves below 0.30.  Some sources also
+bound of 70 and is "oversold" when it moves below 30.  Some sources also
 use thresholds of 80 and 20.
 
 Therefore, moving above the upper threshold is a selling signal, whlie moving
 below the lower threshold is a signal to buy.
 
-NOTE: The result returned by this RSI module is a probability ranging from 0 to
-1.  Most sources seem to show the RSI as a number ranging from 0 to 100.  If
-you wish to have this effect Simply multiply the numbers by 100 to get this
-result.
+Oddly, RSI(14) uses a "smoothing period" of 14 days -- referring to an alpha of
+1/14.  This means the EMA[N]u/EMA[N]d has N set to 27.  This also means the
+alpha is upside of other alpha you might see.  RSI(14) actually uses an alpha
+of ~0.0714, but set_alpha() takes the inverse to make C<$rsi->set_alpha(14)>
+work.
 
-    my $rsi = 100 * $rsi->query;
+If all of the above seems really confusing, no worries: RSI(14) means
+C<set_alpha(14)> (or C<new(14)> and is equivelent to C<set_days(27)>.
+
+=head2 Cutler
+
+There are differing schools of thought on how to calculate this and how
+important it is to stick to precisely the formula Wilder used.  Cutler used
+simple moving averages instead of exponential moving averages.
+
+You can switch between Wilder and Cutler mode with these:
+
+    $rsi->set_cutler; # for simple moving averages
+    $rsi->set_standard; # for exponential moving averages
+
+WARNING: Both of these clear out the value queue!  If you need to track
+both, you'll need two objects. 
 
 =head1 Thanks
 
-Todd Litteken PhD <cl@xganon.com> 
+Todd Litteken <cl@xganon.com> 
+
+Amit Dutt <amit_dutt@hotmail.com>                                                                                       
 
 =head1 AUTHOR
 
@@ -207,6 +218,9 @@ please let me know.
 I normally hang out on #perl on freenode, so you can try to get immediate
 gratification there if you like.  L<irc://irc.freenode.net/perl>
 
+There is also a mailing list with very light traffic that you might want to
+join: L<http://groups.google.com/group/stockmonkey/>.
+
 =head1 COPYRIGHT
 
 Copyright (c) 2008 Paul Miller -- LGPL [Software::License::LGPL_2_1]
@@ -218,7 +232,7 @@ Copyright (c) 2008 Paul Miller -- LGPL [Software::License::LGPL_2_1]
 
 =head1 SEE ALSO
 
-perl(1)
+perl(1), L<Math::Business::StockMonkey>, L<Math::Business::StockMonkey::FAQ>, L<Math::Business::StockMonkey::CookBook>
 
 L<http://en.wikipedia.org/wiki/Relative_Strength_Index>
 
